pub fn assert_commit_sequences_match(
commit_sequences: Vec<Vec<CommittedSubDag>>,
) -> Vec<CommittedSubDag>Expand description
Compare commit sequences across all runs, asserting they are identical. Returns the shortest commit sequence for additional assertions if needed.