pub struct CommitTestFixture {
pub context: Arc<Context>,
pub linearizer: Linearizer,
pub transaction_certifier: TransactionCertifier,
pub commit_finalizer: CommitFinalizer,
/* private fields */
}Expand description
A test fixture that provides all the components needed for testing commit processing, similar to the actual logic in Core::try_commit() and CommitFinalizer::run().
Fields
context: Arc<Context>linearizer: Linearizertransaction_certifier: TransactionCertifiercommit_finalizer: CommitFinalizerImplementations
Sourceimpl CommitTestFixture
impl CommitTestFixture
Sourcepub fn with_options(
num_authorities: usize,
authority_index: u32,
gc_depth: Option<u32>,
) -> Self
pub fn with_options( num_authorities: usize, authority_index: u32, gc_depth: Option<u32>, ) -> Self
Creates a new CommitTestFixture with more options.
pub fn context_with_options( num_authorities: usize, authority_index: u32, gc_depth: Option<u32>, ) -> Arc<Context>
Sourcepub fn try_accept_blocks(&mut self, blocks: Vec<VerifiedBlock>)
pub fn try_accept_blocks(&mut self, blocks: Vec<VerifiedBlock>)
This registers the blocks for reject vote tracking (with no reject votes).
Sourcepub fn add_blocks(&self, blocks: Vec<VerifiedBlock>)
pub fn add_blocks(&self, blocks: Vec<VerifiedBlock>)
Adds blocks to the transaction certifier and dag state. This registers the blocks for reject vote tracking (with no reject votes).
pub fn add_blocks_with_own_votes( &self, blocks_and_votes: Vec<(VerifiedBlock, Vec<TransactionIndex>)>, )
Sourcepub async fn try_commit(
&mut self,
last_decided: Slot,
) -> (Vec<CommittedSubDag>, Slot)
pub async fn try_commit( &mut self, last_decided: Slot, ) -> (Vec<CommittedSubDag>, Slot)
Tries to decide leaders, process and finalize commits, returning finalized commits and the updated last_decided slot.