pub struct TransactionVoteTracker { /* private fields */ }Expand description
TransactionVoteTracker has the following purposes:
- Keeps track of own votes on transactions, and allows the votes to be retrieved later in core after acceptance of the blocks containing the transactions.
- Aggregates reject votes on transactions, and allows the aggregated votes to be retrieved during post-commit finalization.
A transaction is rejected if a quorum of authorities vote to reject it. When this happens, it is guaranteed that no validator can observe a certification of the transaction, with <= f malicious stake.
Implementations
Sourceimpl TransactionVoteTracker
impl TransactionVoteTracker
pub fn new( context: Arc<Context>, block_verifier: Arc<dyn BlockVerifier>, dag_state: Arc<RwLock<DagState>>, ) -> Self
Sourcepub fn add_voted_blocks(
&self,
voted_blocks: Vec<(VerifiedBlock, Vec<TransactionIndex>)>,
)
pub fn add_voted_blocks( &self, voted_blocks: Vec<(VerifiedBlock, Vec<TransactionIndex>)>, )
Stores own reject votes on input blocks, and aggregates reject votes from the input blocks.